@@ -3,7 +3,7 @@ package WWW::Pastebin::PastebinCom::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 use LWP::UserAgent;
 use Carp;
@@ -394,6 +394,18 @@ sub _prepare_optional_api_options {
         push @out_args, api_paste_format => $args->{format};
     }
 
+    if( $args->{owned} and not $args->{private} ) {
+        defined ( $args->{user_key} || $self->user_key )
+            or return $self->set_error(
+                'API user key must be provided to create owned pastes.'
+                    . ' See ->user_key() or ->get_user_key() in the'
+                    . ' documentation.'
+            );
+
+            push @out_args,
+                api_user_key => ( $args->{user_key} || $self->user_key );
+    }
+
     if ( $args->{private} ) {
         defined ( $args->{user_key} || $self->user_key )
             or return $self->_set_error(
@@ -410,6 +422,10 @@ sub _prepare_optional_api_options {
         push @out_args, api_paste_private => 1;
     }
     else {
+        ### DEBUGGING NOTE:
+        ### Pastebin will automatically list duplicate content
+        ### or content with "some" keywords as unlisted
+        ### even if we tell it to go public
         push @out_args, api_paste_private => 0;
     }
 
@@ -1366,6 +1382,34 @@ the behaviour is undefined. B<By default> neither
 C<unlisted> nor C<private> are specified and the created
 paste is public and listed.
 
+I<Note:> Pastebin will automatically list duplicate content
+or content with some keywords as unlisted,
+even if we tell it to go public. It's not a bug in the module.
+
+=head3 C<owned>
+
+    $bin->get_user_key(qw/
+        your_pastebin.com_login
+        your_pastebin.com_password
+    /) or die "$bin";
+
+    print $bin->paste( 'Stuff to paste', owned => 1, )
+        || die "$bin";
+
+B<Optional.> B<Takes> a true or false value.
+B<When set to>
+a true value, will cause the paste you create to be labeled as
+pasted by you instead of C<Guest>.
+B<By default> is set to false and pastes will be labeled
+as created by C<Guest>.
+
+When creating an "owned"
+paste, C<< ->user_key() >>
+accessor method must contain a user key for the user who will own
+this paste. You can either set it directly using C<< ->user_key() >>,
+set it in the constructor using C<user_key> argument, or set it
+indirectly by calling C<< ->get_user_key() >> method.
+
 =head3 C<private>
 
     $bin->get_user_key(qw/
@@ -1385,7 +1429,7 @@ the behaviour is undefined. B<By default> neither
 C<unlisted> nor C<private> are specified and the created
 paste is public and listed.
 
-When creating a private
+When creating a private or "owned"
 paste, C<< ->user_key() >>
 accessor method must contain a user key for the user who will own
 this paste. You can either set it directly using C<< ->user_key() >>,
@@ -1752,82 +1796,31 @@ word C<Error: > is added to the error message.
 The C<examples/> directory of this distribution contains two example
 scripts: one for pasting a file and another for retrieving a paste.
 
-=head1 AUTHOR
+=head1 REPOSITORY
 
-Zoffix Znet, C<< <cpan at zoffix.com> >>
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/WWW-Pastebin-PastebinCom-API>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-www-pastebin-pastebincom-api at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Pastebin-PastebinCom-API>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/WWW-Pastebin-PastebinCom-API/issues>
 
-=head1 SUPPORT
+If you can't access GitHub, you can email your request
+to C<bug-www-pastebin-pastebincom-api at rt.cpan.org>
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc WWW::Pastebin::PastebinCom::API
+Zoffix Znet C<zoffix at cpan.org>, (L<http://zoffix.com/>)
 
-You can also look for information at:
+=head1 CONTRIBUTORS
 
-=over 4
+Philipp Hamer, L<https://github.com/ponzellus>
 
-=item * RT: CPAN's request tracker (report bugs here)
+=head1 LICENSE
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Pastebin-PastebinCom-API>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/WWW-Pastebin-PastebinCom-API>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/WWW-Pastebin-PastebinCom-API>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/WWW-Pastebin-PastebinCom-API/>
-
-=back
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2013 Zoffix Znet.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
 =cut
